maybe rename to epistemic

Ideas:
- The app uses google to authenticate users using OAuth2 with <a href="epistemic://cloud.epistemic.com/secrets/2552345-adsfasd-sadfdga-lk23jr"> these credentials</a>.

sidebar
    - app
    - secrets
    - manifests
    - scripts
    - settings


maybe generating node-red flows?
nlp -> node-red, structurizr

<!-- lemmatization/stemming -->

<!-- https://networkx.org/documentation/stable/tutorial.html -->
